<?php

namespace Litecms\Lead\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Lead\Interfaces\LeadSystemRepositoryInterface;
use Litecms\Lead\Repositories\Eloquent\Filters\LeadSystemPublicFilter;
use Litecms\Lead\Repositories\Eloquent\Presenters\LeadSystemListPresenter;

class LeadSystemPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        LeadSystemRepositoryInterface $lead_system
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.lead.modules'), 'lead_system', guard_url('lead_system'));
        $this->repository = $lead_system;
    }

    /**
     * Show lead_system's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(LeadSystemPublicFilter::class)
            ->setPresenter(LeadSystemListPresenter::class)
            ->select('lead_systems.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('lead::lead_system.names'))
            ->view('lead::public.lead_system.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show lead_system.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('lead::lead_system.name'))
            ->view('lead::public.lead_system.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
